; Output ASCII and HEX characters
;
; Callable routines include:
; OUTCRLF0:		; output CR/LF to SCI to SCI0
; OUTSTRG0:		; output a char string to SCI0
; OUTCHAR0:		; output a char in A to SCI0
; HEXCHAR0:		; output a hex char in A to SCI0
;
;
; ==================== ASCII OUTPUT ROUTINES ====================
; output a string of characters to SCI, index X points
; to text string.  string terminated by '0' EOT character

OUTSTRG0:		; output at string to SCI, string starts
			; at X, terminated by EOT
	psha		; push A
	pshx		; push X

OUTSTRGL:		; output loop 
	ldaa 0,x	; get 1st char
	cmpa #EOT	; end of string?
	beq OUTSTRGE	; exit if 0
OUTE:
	brclr SCI0SR1,$40,OUTE	; loop until TC flag set
	jsr OUTCHAR0	; output char
	inx		; increment X
	bra OUTSTRGL	; loop always

OUTSTRGE:		; output loop end
	jsr OUTCRLF0	; CR/LF for next output
	pulx		; restore X
	pula		; restore A
	rts		; return

; Output a Carriage return and a line feed.  Returns a = cr.
OUTCRLF0:
	LDAA #$0A	; get LF
	JSR OUTCHAR0	; send it out
	LDAA #$0D	; get CR

	JSR OUTCHAR0	; send it out

	LDAA #$00

	JSR OUTCHAR0	; output padding

	LDAA #$0D

	RTS


OUTCHAR0:		; Output a char in A to SCI

	brclr SCI0SR1,#$80,OUTCHAR0	; loop until TDRE bit set
	LDAB SCI0SR1	; read status
	ANDA #$7F	; mask parity
	STAA SCI0DRL	; send character
	RTS

CLEAR:
	ldaa SCI0SR1	; dummy read
	ldaa SCI0DRL	; dummy read
	rts		; return


;==================== HEX OUTPUT ROUTINES ====================

HEX2:			; output 2 hex bytes in A to SCI
	psha		; push A
	lsra
	lsra
	lsra
	lsra		; shift hi nibble to low nibble
	jsr HEXOUT	; output hex char (hi nibble)
	pula		; restore A
	jsr HEXOUT	; output hex char (lo nibble)
	rts		; return

HEXOUT:			; send HEX Char to SCI
	anda #$0f	; mask hi nibble
	cmpa #$09	; check for letter
	bhi HEX01	; convert to ASCII
	adda #$30	; add ASCII offset
	jsr OUTCHAR0	; output char to SCI
	rts		; return

HEX01:			; convert to ASCII
         adda #$37	; convet a-f to ASCII
         jsr OUTCHAR0	; output char to SCI
         rts	; return

HEX4:			; output 4 hex bytes in X
         pshx		; save X
         pula		; low byte to A
         jsr HEX2	; output hex byte in A
         pula		; high byte to A
         jsr HEX2	; output hex byte in A
         rts		; return